@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.121-9-g1e8107f
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.122-7-g6a4f4e3
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 
-our $VERSION = '0.122';
+our $VERSION = '0.123';
 
 use Moose;
 with
@@ -335,6 +335,7 @@ sub configure
 
         # Before Release
         [ 'CheckStrictVersion'  => { decimal_only => 1 } ],
+        'CheckMetaResources',
         [ 'Git::Check'          => 'initial check' => { allow_dirty => [''] } ],
         'Git::CheckFor::MergeConflicts',
         [ 'Git::CheckFor::CorrectBranch' => { ':version' => '0.004', release_branch => 'master' } ],
@@ -447,7 +448,7 @@ sub configure
 
     push @plugins, (
         # listed last, to be sure we run at the very end of each phase
-        [ 'VerifyPhases' => 'PHASE VERIFICATION' ],
+        [ 'VerifyPhases' => 'PHASE VERIFICATION' => { ':version' => '0.015' } ],
     ) if ($ENV{USER} // '') eq 'ether';
 
     $self->add_plugins(@plugins);
@@ -480,7 +481,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.122
+version 0.123
 
 =head1 SYNOPSIS
 
@@ -841,6 +842,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     ; listed last, to be sure we run at the very end of each phase
     ; only performed if $ENV{USER} eq 'ether'
     [VerifyPhases / PHASE VERIFICATION]
+    :version = 0.015
 
 =for Pod::Coverage configure mvp_multivalue_args
 
@@ -971,7 +973,7 @@ you'll need to provide this yourself.
 
 Available since 0.053.
 
-A boolean option, that when set, removes the use of all plugins that use the
+A boolean option that, when set, removes the use of all plugins that use the
 network (generally for comparing metadata against PAUSE, and querying the
 remote git server), as well as blocking the use of the C<release> command.
 Defaults to false; can also be set with the environment variable C<DZIL_AIRPLANE>.
@@ -992,7 +994,7 @@ defaults are appended to, rather than overwritten.
 
 Available since 0.051.
 
-A boolean option, that when set, uses
+A boolean option that, when set, uses
 L<[SurgicalPodWeaver]|Dist::Zilla::Plugin::SurgicalPodWeaver> instead of
 L<[PodWeaver]|Dist::Zilla::Plugin::SurgicalPodWeaver>, but with all the same
 options. Defaults to false.
@@ -1027,7 +1029,7 @@ file (if the C<licence> configuration is not provided).
 
 Available since 0.122.
 
-A boolean option, that when set, removes <[UploadToCPAN]|Dist::Zilla::Plugin::UploadToCPAN> from the plugin list
+A boolean option that, when set, removes <[UploadToCPAN]|Dist::Zilla::Plugin::UploadToCPAN> from the plugin list
 and replaces it with <[FakeRelease]|Dist::Zilla::Plugin::FakeRelease>.
 Defaults to false; can also be set with the environment variable C<FAKE_RELEASE>.
 
